# RAM loadable binaries

* The RAM loadable binaries have been generated against [IDF-v5.1](https://github.com/espressif/esp-idf/releases/tag/v5.1)

* The source code can be found at the [Firmware source code feature branch](https://github.com/espressif/esp-cryptoauthlib/tree/feature/add_firmware_source_code)
